// Test code to help understand the effect of FFT
// The code takes one input image and generate four output images
//   - magnitude
//   - phase
//   - magnitude after log transformation (not provided as log tran
//     has not been implemented yet)
//   - image after ifft

#include "Image.h"
#include "Dip.h"
#include <iostream>
#include <cstdlib>
#include <cmath>             // new: for log()
using namespace std;

#define Usage "./testfft inimg\n"

int main(int argc, char **argv)
{
  Image inimg, outimg, mag, phase, maglog;
  int nr, nc;
  int i, j;

  if (argc < 2) {
    cout << Usage;
    exit(3);
  }

  // read in image
  inimg = readImage(argv[1]);
  nr = inimg.getRow();
  nc = inimg.getCol();

  // allocate memory
  mag.createImage(nr, nc);
  phase.createImage(nr, nc);
  outimg.createImage(nr, nc);

  // Fourier transform
  fft(inimg, mag, phase);

  // magnitude after log transformation
  //  maglog = logtran(mag);
  maglog = inimg;           // new: allocate memory
  for (i=0; i<nr; i++)      // new: perform log transformation to compress the dynamic range
    for (j=0; j<nc; j++)    // new: you should be able to call the logtran() you designed in proj2
      maglog(i,j) = log(1+fabs(mag(i,j)));

  // inverse Fourier transform
  ifft(outimg, mag, phase);

  // output image
  cout << "Write magnitude image ..." << endl;
  writeImage(mag, "testmag.pgm", 1);
  cout << "Write magnitude image AFTER log transformation ..." << endl;
  writeImage(maglog, "testmaglog.pgm", 1);
  cout << "Write phase image ..." << endl;
  writeImage(phase, "testphase.pgm", 1);
  cout << "Write image after inverse Fourier transform ..." << endl;
  writeImage(outimg, "testifft.pgm");

  return 0;
}

